==> kubernetes-model-kustomize-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/PatchFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface PatchFluent<A extends PatchFluent<A>> extends Fluent<A>{
  public A addToOptions(String key,Boolean value);
  public A addToOptions(Map<String,Boolean> map);
  public A removeFromOptions(String key);
  public A removeFromOptions(Map<String,Boolean> map);
  public Map<String,Boolean> getOptions();
  public <K,V>A withOptions(Map<String,Boolean> options);
  public Boolean hasOptions();
  public String getPatch();
  public A withPatch(String patch);
  public Boolean hasPatch();
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public Selector getTarget();
  public Selector buildTarget();
  public A withTarget(Selector target);
  public Boolean hasTarget();
  public PatchFluent.TargetNested<A> withNewTarget();
  public PatchFluent.TargetNested<A> withNewTargetLike(Selector item);
  public PatchFluent.TargetNested<A> editTarget();
  public PatchFluent.TargetNested<A> editOrNewTarget();
  public PatchFluent.TargetNested<A> editOrNewTargetLike(Selector item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface TargetNested<N> extends Nested<N>,SelectorFluent<PatchFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}

==> kubernetes-model-kustomize-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/PatchFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PatchFluent<A extends PatchFluent<A>> extends Fluent<A>{
  public A addToOptions(String key,Boolean value);
  public A addToOptions(Map<String,Boolean> map);
  public A removeFromOptions(String key);
  public A removeFromOptions(Map<String,Boolean> map);
  public Map<String,Boolean> getOptions();
  public <K,V>A withOptions(Map<String,Boolean> options);
  public Boolean hasOptions();
  public String getPatch();
  public A withPatch(String patch);
  public Boolean hasPatch();
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public Selector getTarget();
  public Selector buildTarget();
  public A withTarget(Selector target);
  public Boolean hasTarget();
  public PatchFluent.TargetNested<A> withNewTarget();
  public PatchFluent.TargetNested<A> withNewTargetLike(Selector item);
  public PatchFluent.TargetNested<A> editTarget();
  public PatchFluent.TargetNested<A> editOrNewTarget();
  public PatchFluent.TargetNested<A> editOrNewTargetLike(Selector item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface TargetNested<N> extends Nested<N>,SelectorFluent<PatchFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}
